==> ejc-bfyjerp-impl-3.0.0-20241030.030540-4-sources.jar: com/ejianc/business/finance/bean/AccountRegisterEntity.java <==
package com.ejianc.business.finance.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 出纳资金-账户登记
 * 
 * @author generator
 * 
 */
 @TableName("ejc_finance_account_register")
public class AccountRegisterEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="open_account_id")
    private Long openAccountId; // 开户申请主键
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0-自由态，1-已提交，2-审批中，3-审批通过，4-审批不通过
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="corp_id")
    private Long corpId; // 公司名称id
    @TableField(value="corp_code")
    private String corpCode; // 公司编码
    @TableField(value="corp_name")
    private String corpName; // 公司名称
    @TableField(value="account_name")
    private String accountName; // 账户名称
    @TableField(value="account_time")
    private Date accountTime; // 开户时间
    @TableField(value="legal_person")
    private String legalPerson; // 法人
    @TableField(value="account_xz_id")
    private Long accountXzId; // 账户性质
    @TableField(value="account_xz_name")
    private String accountXzName; // 账户性质名称
    @TableField(value="bank_account")
    private String bankAccount; // 银行账号
    @TableField(value="bank_name")
    private String bankName; // 开户行
    @TableField(value="commit_user_id")
    private Long commitUserId; // 提交UK
    @TableField(value="commit_user_name")
    private String commitUserName; // 提交UK名称
    @TableField(value="approve_user_id")
    private Long approveUserId; // 审核UK
    @TableField(value="approve_user_name")
    private String approveUserName; // 审核UK名称
    @TableField(value="reconciliation_name")
    private String reconciliationName; // 对账人名称
    @TableField(value="reconciliation_type")
    private String reconciliationType; // 对账方式
    @TableField(value="reconciliation_time")
    private String reconciliationTime; // 对账时间
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 项目所属组织
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目所属组织编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 项目所属组织名称
    @TableField(value="accountant_id")
    private Long accountantId; // 项目会计
    @TableField(value="accountant_name")
    private String accountantName; // 项目会计名称
    @TableField(value="manager_id")
    private Long managerId; // 业务经理
    @TableField(value="manager_name")
    private String managerName; // 业务经理名称
    @TableField(value="account_status")
    private Integer accountStatus; // 账户状态：1-在用 2-销户
    @TableField(value="un_account_time")
    private Date unAccountTime; // 销户时间
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    
    
    

    public Long getOpenAccountId() {
        return openAccountId;
    }

    public void setOpenAccountId(Long openAccountId) {
        this.openAccountId = openAccountId;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getCorpId() {
        return corpId;
    }

    public void setCorpId(Long corpId) {
        this.corpId = corpId;
    }
    public String getCorpCode() {
        return corpCode;
    }

    public void setCorpCode(String corpCode) {
        this.corpCode = corpCode;
    }
    public String getCorpName() {
        return corpName;
    }

    public void setCorpName(String corpName) {
        this.corpName = corpName;
    }
    public String getAccountName() {
        return accountName;
    }

    public void setAccountName(String accountName) {
        this.accountName = accountName;
    }
    public Date getAccountTime() {
        return accountTime;
    }

    public void setAccountTime(Date accountTime) {
        this.accountTime = accountTime;
    }
    public String getLegalPerson() {
        return legalPerson;
    }

    public void setLegalPerson(String legalPerson) {
        this.legalPerson = legalPerson;
    }
    public Long getAccountXzId() {
        return accountXzId;
    }

    public void setAccountXzId(Long accountXzId) {
        this.accountXzId = accountXzId;
    }
    public String getAccountXzName() {
        return accountXzName;
    }

    public void setAccountXzName(String accountXzName) {
        this.accountXzName = accountXzName;
    }
    public String getBankAccount() {
        return bankAccount;
    }

    public void setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
    }
    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }
    public Long getCommitUserId() {
        return commitUserId;
    }

    public void setCommitUserId(Long commitUserId) {
        this.commitUserId = commitUserId;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public Long getApproveUserId() {
        return approveUserId;
    }

    public void setApproveUserId(Long approveUserId) {
        this.approveUserId = approveUserId;
    }
    public String getApproveUserName() {
        return approveUserName;
    }

    public void setApproveUserName(String approveUserName) {
        this.approveUserName = approveUserName;
    }
    public String getReconciliationName() {
        return reconciliationName;
    }

    public void setReconciliationName(String reconciliationName) {
        this.reconciliationName = reconciliationName;
    }
    public String getReconciliationType() {
        return reconciliationType;
    }

    public void setReconciliationType(String reconciliationType) {
        this.reconciliationType = reconciliationType;
    }
    public String getReconciliationTime() {
        return reconciliationTime;
    }

    public void setReconciliationTime(String reconciliationTime) {
        this.reconciliationTime = reconciliationTime;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getAccountantId() {
        return accountantId;
    }

    public void setAccountantId(Long accountantId) {
        this.accountantId = accountantId;
    }
    public String getAccountantName() {
        return accountantName;
    }

    public void setAccountantName(String accountantName) {
        this.accountantName = accountantName;
    }
    public Long getManagerId() {
        return managerId;
    }

    public void setManagerId(Long managerId) {
        this.managerId = managerId;
    }
    public String getManagerName() {
        return managerName;
    }

    public void setManagerName(String managerName) {
        this.managerName = managerName;
    }
    public Integer getAccountStatus() {
        return accountStatus;
    }

    public void setAccountStatus(Integer accountStatus) {
        this.accountStatus = accountStatus;
    }
    public Date getUnAccountTime() {
        return unAccountTime;
    }

    public void setUnAccountTime(Date unAccountTime) {
        this.unAccountTime = unAccountTime;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    
}

==> ejc-bfyjerp-impl-3.0.0-20241108.084022-22-sources.jar: com/ejianc/business/finance/bean/AccountRegisterEntity.java <==
package com.ejianc.business.finance.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 出纳资金-账户登记
 * 
 * @author generator
 * 
 */
 @TableName("ejc_finance_account_register")
public class AccountRegisterEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="open_account_id")
    private Long openAccountId; // 开户申请主键
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0-自由态，1-已提交，2-审批中，3-审批通过，4-审批不通过
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="corp_id")
    private Long corpId; // 公司名称id
    @TableField(value="corp_code")
    private String corpCode; // 公司编码
    @TableField(value="corp_name")
    private String corpName; // 公司名称
    @TableField(value="account_name")
    private String accountName; // 账户名称
    @TableField(value="account_time")
    private Date accountTime; // 开户时间
    @TableField(value="legal_person")
    private String legalPerson; // 法人
    @TableField(value="account_xz_id")
    private Long accountXzId; // 账户性质
    @TableField(value="account_xz_name")
    private String accountXzName; // 账户性质名称
    @TableField(value="bank_account")
    private String bankAccount; // 银行账号
    @TableField(value="bank_name")
    private String bankName; // 开户行
    @TableField(value="commit_user_id")
    private Long commitUserId; // 提交UK
    @TableField(value="commit_user_name")
    private String commitUserName; // 提交UK名称
    @TableField(value="approve_user_id")
    private Long approveUserId; // 审核UK
    @TableField(value="approve_user_name")
    private String approveUserName; // 审核UK名称
    @TableField(value="reconciliation_name")
    private String reconciliationName; // 对账人名称
    @TableField(value="reconciliation_type")
    private String reconciliationType; // 对账方式
    @TableField(value="reconciliation_time")
    private String reconciliationTime; // 对账时间
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 项目所属组织
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目所属组织编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 项目所属组织名称
    @TableField(value="accountant_id")
    private Long accountantId; // 项目会计
    @TableField(value="accountant_name")
    private String accountantName; // 项目会计名称
    @TableField(value="manager_id")
    private Long managerId; // 业务经理
    @TableField(value="manager_name")
    private String managerName; // 业务经理名称
    @TableField(value="account_status")
    private Integer accountStatus; // 账户状态：1-在用 2-销户
    @TableField(value="un_account_time")
    private Date unAccountTime; // 销户时间
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="project_type")
    private String projectType; // 是否属于项目 1-项目，2-公司

    public String getProjectType() {
        return projectType;
    }

    public void setProjectType(String projectType) {
        this.projectType = projectType;
    }

    public Long getOpenAccountId() {
        return openAccountId;
    }

    public void setOpenAccountId(Long openAccountId) {
        this.openAccountId = openAccountId;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getCorpId() {
        return corpId;
    }

    public void setCorpId(Long corpId) {
        this.corpId = corpId;
    }
    public String getCorpCode() {
        return corpCode;
    }

    public void setCorpCode(String corpCode) {
        this.corpCode = corpCode;
    }
    public String getCorpName() {
        return corpName;
    }

    public void setCorpName(String corpName) {
        this.corpName = corpName;
    }
    public String getAccountName() {
        return accountName;
    }

    public void setAccountName(String accountName) {
        this.accountName = accountName;
    }
    public Date getAccountTime() {
        return accountTime;
    }

    public void setAccountTime(Date accountTime) {
        this.accountTime = accountTime;
    }
    public String getLegalPerson() {
        return legalPerson;
    }

    public void setLegalPerson(String legalPerson) {
        this.legalPerson = legalPerson;
    }
    public Long getAccountXzId() {
        return accountXzId;
    }

    public void setAccountXzId(Long accountXzId) {
        this.accountXzId = accountXzId;
    }
    public String getAccountXzName() {
        return accountXzName;
    }

    public void setAccountXzName(String accountXzName) {
        this.accountXzName = accountXzName;
    }
    public String getBankAccount() {
        return bankAccount;
    }

    public void setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
    }
    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }
    public Long getCommitUserId() {
        return commitUserId;
    }

    public void setCommitUserId(Long commitUserId) {
        this.commitUserId = commitUserId;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public Long getApproveUserId() {
        return approveUserId;
    }

    public void setApproveUserId(Long approveUserId) {
        this.approveUserId = approveUserId;
    }
    public String getApproveUserName() {
        return approveUserName;
    }

    public void setApproveUserName(String approveUserName) {
        this.approveUserName = approveUserName;
    }
    public String getReconciliationName() {
        return reconciliationName;
    }

    public void setReconciliationName(String reconciliationName) {
        this.reconciliationName = reconciliationName;
    }
    public String getReconciliationType() {
        return reconciliationType;
    }

    public void setReconciliationType(String reconciliationType) {
        this.reconciliationType = reconciliationType;
    }
    public String getReconciliationTime() {
        return reconciliationTime;
    }

    public void setReconciliationTime(String reconciliationTime) {
        this.reconciliationTime = reconciliationTime;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getAccountantId() {
        return accountantId;
    }

    public void setAccountantId(Long accountantId) {
        this.accountantId = accountantId;
    }
    public String getAccountantName() {
        return accountantName;
    }

    public void setAccountantName(String accountantName) {
        this.accountantName = accountantName;
    }
    public Long getManagerId() {
        return managerId;
    }

    public void setManagerId(Long managerId) {
        this.managerId = managerId;
    }
    public String getManagerName() {
        return managerName;
    }

    public void setManagerName(String managerName) {
        this.managerName = managerName;
    }
    public Integer getAccountStatus() {
        return accountStatus;
    }

    public void setAccountStatus(Integer accountStatus) {
        this.accountStatus = accountStatus;
    }
    public Date getUnAccountTime() {
        return unAccountTime;
    }

    public void setUnAccountTime(Date unAccountTime) {
        this.unAccountTime = unAccountTime;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    
}
